@@ -13,8 +13,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from unittest import mock
+
 from fixtures import MonkeyPatch
-import mock
 
 from config_tempest.services.image import ImageService
 from config_tempest.tempest_conf import TempestConf
@@ -33,6 +34,7 @@ class TestImageService(BaseServiceTest):
     def setUp(self):
         super(TestImageService, self).setUp()
         self.Service = ImageService("ServiceName",
+                                    "ServiceType",
                                     self.FAKE_URL,
                                     self.FAKE_TOKEN,
                                     disable_ssl_validation=False)
